summaryrefslogtreecommitdiff
path: root/src/cairo-error-private.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/cairo-error-private.h')
-rw-r--r--[-rwxr-xr-x]src/cairo-error-private.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/cairo-error-private.h b/src/cairo-error-private.h
index ea9c2ea31..178078ad6 100755..100644
--- a/src/cairo-error-private.h
+++ b/src/cairo-error-private.h
@@ -46,10 +46,13 @@
CAIRO_BEGIN_DECLS
/* Sure wish C had a real enum type so that this would be distinct
* from #cairo_status_t. Oh well, without that, I'll use this bogus 100
* offset. We want to keep it fit in int8_t as the compiler may choose
- * that for #cairo_status_t */
+ * that for #cairo_status_t
+ */
enum _cairo_int_status {
CAIRO_INT_STATUS_SUCCESS = 0,
@@ -90,6 +93,7 @@ enum _cairo_int_status {
CAIRO_INT_STATUS_DEVICE_ERROR,
CAIRO_INT_STATUS_INVALID_MESH_CONSTRUCTION,
CAIRO_INT_STATUS_DEVICE_FINISHED,
+ CAIRO_INT_STATUS_JBIG2_GLOBAL_MISSING,
CAIRO_INT_STATUS_LAST_STATUS,
@@ -46,10 +46,13 @@
CAIRO_BEGIN_DECLS
-/* Sure wish C had a real enum type so that this would be distinct
+/* _cairo_int_status: internal status
+ *
+ * Sure wish C had a real enum type so that this would be distinct
* from #cairo_status_t. Oh well, without that, I'll use this bogus 100
* offset. We want to keep it fit in int8_t as the compiler may choose